summaryrefslogtreecommitdiffstats
path: root/kopete/libkopete/ui/kopetelistviewitem.h
diff options
context:
space:
mode:
authorTimothy Pearson <kb9vqf@pearsoncomputing.net>2011-12-15 15:49:40 -0600
committerTimothy Pearson <kb9vqf@pearsoncomputing.net>2011-12-15 15:49:40 -0600
commit808e453c56036211f57482ed847d54aca01bba68 (patch)
tree75515d5768dea10d4fbe4cd772e0a89c1c4b3aa9 /kopete/libkopete/ui/kopetelistviewitem.h
parentcd9b9ed7fd0ac8a75106148254aa58e2e5c04863 (diff)
downloadtdenetwork-808e453c56036211f57482ed847d54aca01bba68.tar.gz
tdenetwork-808e453c56036211f57482ed847d54aca01bba68.zip
Rename a number of old tq methods that are no longer tq specific
Diffstat (limited to 'kopete/libkopete/ui/kopetelistviewitem.h')
-rw-r--r--kopete/libkopete/ui/kopetelistviewitem.h36
1 files changed, 18 insertions, 18 deletions
diff --git a/kopete/libkopete/ui/kopetelistviewitem.h b/kopete/libkopete/ui/kopetelistviewitem.h
index 0868afab..bd2a2968 100644
--- a/kopete/libkopete/ui/kopetelistviewitem.h
+++ b/kopete/libkopete/ui/kopetelistviewitem.h
@@ -44,9 +44,9 @@ public:
Component *componentAt( const TQPoint &pt );
/** Repaint this item */
- virtual void tqrepaint() = 0;
- /** Retqlayout this item */
- virtual void retqlayout() = 0;
+ virtual void repaint() = 0;
+ /** Relayout this item */
+ virtual void relayout() = 0;
/**
* Get the tool tip string and rectangle for a tip request at position
@@ -64,7 +64,7 @@ protected:
virtual void componentRemoved( Component *component );
/** A child item has been resized */
virtual void componentResized( Component *component );
- /** Remove all tqchildren */
+ /** Remove all children */
virtual void clear();
/** @internal animate items */
@@ -112,16 +112,16 @@ public:
* @param rect the new rectangle this component will paint in, relative to the painter
* passed to the paint() function by the parent item.
*/
- virtual void tqlayout( const TQRect &rect );
+ virtual void layout( const TQRect &rect );
/**
* Paint this item, inside the rectangle returned by rect().
- * The default implementation calls paint on all tqchildren.
+ * The default implementation calls paint on all children.
*/
virtual void paint( TQPainter *painter, const TQColorGroup &cg );
- void tqrepaint();
- void retqlayout();
+ void repaint();
+ void relayout();
/**
* @return the rect this component was allocated last time it was laid out
@@ -196,19 +196,19 @@ public:
protected:
/**
* Change the minimum width, in pixels, this component requires in order
* to be at all useful. Note: do not call this from your tqlayout() function.
* @param width the minimum width
* @return true if the size has actually changed, false if it's been set to
* the existing values. if it returns true, you do not need to retqlayout,
* since the parent component will do that for you.
*/
bool setMinWidth( int width );
/**
* Change the minimum height, in pixels, this component requires in order
* to be at all useful. Note: do not call this from your tqlayout() function.
* @param height the minimum height
* @return true if the size has actually changed, false if it's been set to
* the existing values. If it returns true, you do not need to retqlayout,
* since the parent component will do that for you.
*/
bool setMinHeight( int height );
@@ -236,7 +236,7 @@ public:
BoxComponent( ComponentBase *parent, Direction dir =Horizontal );
~BoxComponent();
- virtual void tqlayout( const TQRect &rect );
+ virtual void layout( const TQRect &rect );
virtual int widthForHeight( int height );
virtual int heightForWidth( int width );
@@ -267,7 +267,7 @@ public:
virtual void reloadTheme();
- virtual void tqlayout(const TQRect &rect);
+ virtual void layout(const TQRect &rect);
virtual int widthForHeight(int height);
virtual int heightForWidth(int width);
@@ -290,7 +290,7 @@ public:
virtual void reloadTheme();
- virtual void tqlayout(const TQRect &rect);
+ virtual void layout(const TQRect &rect);
virtual int widthForHeight(int height);
virtual int heightForWidth(int width);
@@ -406,7 +406,7 @@ public:
* Dtor
*/
~DisplayNameComponent();
- void tqlayout( const TQRect& rect );
+ void layout( const TQRect& rect );
TQString text();
void setText( const TQString& text );
@@ -460,8 +460,8 @@ public:
Item( TQListViewItem *parent, TQObject *owner = 0, const char *name = 0 );
~Item();
- void tqrepaint();
- void retqlayout();
+ void repaint();
+ void relayout();
void setup();
virtual void paintCell( TQPainter *p, const TQColorGroup &cg, int column, int width, int align );
@@ -196,19 +196,19 @@ public:
/**
* Change the minimum width, in pixels, this component requires in order
- * to be at all useful. Note: do not call this from your tqlayout() function.
+ * to be at all useful. Note: do not call this from your layout() function.
* @param width the minimum width
* @return true if the size has actually changed, false if it's been set to
@@ -196,19 +196,19 @@ public:
* @param width the minimum width
* @return true if the size has actually changed, false if it's been set to
- * the existing values. if it returns true, you do not need to retqlayout,
+ * the existing values. if it returns true, you do not need to relayout,
* since the parent component will do that for you.
*/
@@ -196,19 +196,19 @@ public:
/**
* Change the minimum height, in pixels, this component requires in order
- * to be at all useful. Note: do not call this from your tqlayout() function.
+ * to be at all useful. Note: do not call this from your layout() function.
* @param height the minimum height
* @return true if the size has actually changed, false if it's been set to
@@ -196,19 +196,19 @@ public:
* @param height the minimum height
* @return true if the size has actually changed, false if it's been set to
- * the existing values. If it returns true, you do not need to retqlayout,
+ * the existing values. If it returns true, you do not need to relayout,
* since the parent component will do that for you.
*/